summaryrefslogtreecommitdiffstats
path: root/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java
diff options
context:
space:
mode:
Diffstat (limited to 'dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java')
-rw-r--r--dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java b/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java
index 6705ac20..18e7133e 100644
--- a/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java
+++ b/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/layout/LoginWindowLayout.java
@@ -19,6 +19,7 @@ import javax.swing.border.TitledBorder;
import org.apache.log4j.Logger;
import org.openslx.bwlp.thrift.iface.Organization;
+import org.openslx.dozmod.Branding;
import org.openslx.dozmod.gui.Gui;
import org.openslx.dozmod.gui.control.ComboBox;
import org.openslx.dozmod.gui.control.ComboBox.ComboBoxRenderer;
@@ -47,7 +48,7 @@ public abstract class LoginWindowLayout extends JDialog {
// authentication method to use for login attempts
protected LOGIN_TYPE loginType = null;
- private static final String TITLE = "bwLehrpool-Suite - Login";
+ private static final String TITLE = Branding.getApplicationName() + " - Login";
private static final String AUTH_TYPE_LABEL = "Authentifizierungsart";
private static final String LOGIN_FORM_LABEL = "Zugangsdaten";
private static final String ADVANCED_LABEL = "Erweitert";
@@ -176,12 +177,12 @@ public abstract class LoginWindowLayout extends JDialog {
}
/**
* @return ImageIcon of the standard bwLehrpool logo scaled to the login
* window size
*/
private ImageIcon getScaledLogo() {
try {
- ImageIcon image = ResourceLoader.getIcon("/img/bwLehrpool-logo.png");
+ ImageIcon image = ResourceLoader.getIcon("/img/service-logo.png");
Rectangle screenSize = Gui.getMonitorFromRectangle(getBounds(), true)
.getDefaultConfiguration()
.getBounds();
@@ -176,12 +177,12 @@ public abstract class LoginWindowLayout extends JDialog {
}
/**
- * @return ImageIcon of the standard bwLehrpool logo scaled to the login
+ * @return ImageIcon of the standard service logo scaled to the login
* window size
*/